*****************
Benchmark modules
*****************

.. automodule:: orion.benchmark
   :members:

.. toctree::
   :maxdepth: 2
   :caption: Benchmark modules of Oríon

   benchmark/benchmark_client
   benchmark/task
   benchmark/assessment
